/*
 PC 4182 MPhys Project - Classification of Gravitational Microlensing Light Curves
 
 Configuration values for the main program
 
 Started: 23/03/06
 Last Modified: 12/05/06
 
 Mike Peel (http://www.mikepeel.net/) & Matthew Dennison (matthew.dennison@manchester.ac.uk)
 */


/*
 Paths for inputting and outputting the data. All strings. Should be enclosed by " 's. Max of 100 characters.
 Defunct - now do this by command line.
 */
#define INPUT_DIRECTORY			"/BLG206.7/bob/"
#define OUTPUT_DIRECTORY		"/BLG206.7/bob-graphs/"

/*
 Switches for doing various things, set before compile time.
 Set to 1 to enable a specific feature, 0 to disable it.
 */
//
// Cleaning data
//
#define SORT_DATA				0
#define NORMALIZE_TIMES			0


//
// Statistics
//
#define NUM_OUTSIDE_ERROR		0
#define CALC_MEAN				0
#define CALC_MEDIAN				0
// Create magnitude histograms based on each season and every NUM_TIME_BIN time points?
// Also requires CALC_MEDIAN, and appropriate values for MIN_MAGNITUDE, MAX_MAGNITUDE,  NUM_BAG_BINS and NUM_OBSERVE_TIMES below.
// Season times and numbers hard-wired.
#define SEASON_MAG_HISTOGRAM	0

//
// Period Finding
//
// First stage - calculate a period model?
#define CALC_PERIODS			0
#define CALC_PERIOD_FIT			0
// Output a table of the periods onto the command line?
#define PRINT_PERIODS			0
// Second stage - debug period model?
#define DEBUG_PERIOD_FIT		0
#define DEBUG_PERIOD_FIT_ALL	0
// Third stage - limits on results
// Set a maximum chi-squared/#DoF for the period fit? (set value below)
#define MAX_PERIOD_CHI			0
// Fourth stage - plot period model?
#define CREATE_PERIOD_GRAPHS	0


//
// Identification of microlensing candidates
//
#define IDENTIFY_CANDIDATES		0
// Which ID mechanism wants to be used?
#define USE_OGLE_ID				0
#define USE_MACHO_ID			0
#define USE_LSFIT_ID			0
#define USE_HOMEBREW_ID			0
#define USE_NUMROW_ID			0
#define DEBUG_CANDIDATES		0


//
// Theoretical microlensing models
//
// First stage - calculate models?
#define CALC_LSFIT				0
// Force f_l = 1 in the model?
#define CALC_LSFIT_F_L			0
// Second stage - debug fits?
#define DEBUG_FIT				0
#define DEBUG_FIT_ALL			0
// Fourth stage - limits on results
// Set a maximum chi-squared/#DoF for interesting events? (set value below)
#define MAX_FIT_CHI				0
// Third stage - output graphs?
#define PLOT_LSFIT_GRAPHS		0
// Plot the LSF model?
#define PLOT_MODEL				0

//
// Fitting a constant luminosity
//
#define DEBUG_BASE_FIT			0
#define DEBUG_BASE_FIT_ALL		0


//
// Monte Carlo
//
// First Step - initial preparation
#define GET_MIN_MAX_MAG			0
#define COUNT_NUM_TIMES			0
// Second Step - creating error information
#define GENERATE_ERROR_TABLE	0
// Third Step - running Monte Carlo
#define MONTE_CARLO				0
// Fourth step - outputting the data. Do we want non-detected montecarlo events?
#define MONTE_CARLO_LOST		0
// Interpolate error table? Currently doesn't work / isn't programmed in.
#define INTERPOLATE_ERROR_TABLE	0


//
// Outputting data
//
#define CREATE_INFO_FILE		0




/*
 Define the 'magic' numbers
 */
// The maximum number of entries in a file
#define N						500
// Max number of stars to process. Set this to some large value to disable the limit.
#define MAX_NUM_STARS			100000000
// How many times do we want to loop around the data set?
// Only really of use for extended Monte Carlo testing
#define NUM_LOOPS_MAX			1


//
// Period-finding numbers - see period.c
//
// The initial number of frequencies to look at
#define N_FREQUENCIES			500
// The range of periods to look at, in days
#define MIN_PERIOD				5.0
#define MAX_PERIOD				500.0
// The size of subsequent batches of frequencies. This should not be higher than N_FREQUENCIES.
#define N_BATCH_FREQUENCIES		50
// The final accurary of the period required, in days
#define PERIOD_ACCURACY			0.01
// Maximum value of the chi-squared/#DoF of the period?
#define MAX_PERIOD_CHI_VALUE	10

//
// Period LSF numbers - see fit_period.c
//
// Number of parameters - here, 9.
#define NUM_PERIOD_PARAMETERS	9

// Number of constant baseline params
#define NUM_BASE_PARAMETERS		1


//
// Candidates - see candidates.c
//
// OGLE
// Fraction of dataset to use for the window length - normally 0.50.
#define OGLE_WINDOW_LENGTH		0.5

// NUMROW
#define NUM_IN_ROW				4

// LSFit
// Max chi-squared/#DoF values for local and global chi's
#define LSF_MAX_CHI_GLOBAL		20
#define LSF_MAX_CHI_LOCAL		10
// Min/max values for t_einstein
#define LSF_T_EINSTEIN_MIN		1
#define LSF_T_EINSTEIN_MAX		200
// Min/max values of u_min
#define LSF_U_MIN_MIN			0.01
#define LSF_U_MIN_MAX			2.0
// Max value for f_l
#define LSF_F_L					2.0
// Max value for the error on t_einstein
#define LSF_T_EINSTEIN_ERR		10
// Max value for the error on u_min
#define LSF_U_MIN_ERR			1.0
// Max value for the error on f_l
#define LSF_F_L_ERR				1.0


//
// Least Square Fit for the fitting of the microlensing model - see fit.c
//
// Number of parameters - here, 5.
#define NUM_PARAMETERS			5
// Max number of fitting attempts
#define MAX_FIT_ITERATIONS		100
// Max chi-squared/#DoF values for local and global chi's
#define MAX_FIT_CHI_GLOBAL		20
#define MAX_FIT_CHI_LOCAL		10


//
// Monte Carlo settings
//
// Maximum and mininum magnitudes - use GET_MIN_MAX_MAG above if these are not already known, or set to a larger and lower value than is possible - program will be slightly slower in this case. These should not be changed after you've run the error table process.
#define MAX_MAGNITUDE			24.843
// Note that 'minimum' should be the lowest numerical value - not the highest.
#define MIN_MAGNITUDE			11.177
#define NUM_MAG_BINS			100
// Number of observation times - use COUNT_NUM_TIMES above if this is not already known (setting this to an overestimated value)
#define NUM_OBSERVE_TIMES		161
// If interpolation is needed, to improve monte carlo accuracy, enable it above and set the number of bins here. Currently not working.
#define NUM_MAG_INTERPOLATED	1000

// Settings for the generation of events
// Min/max values for t_einstein
#define MC_T_EINSTEIN_MIN		1
#define MC_T_EINSTEIN_MAX		200
// Min/max values of u_min
#define MC_U_MIN_MIN			0.01
#define MC_U_MIN_MAX			1.0
// Value for f_l
#define MC_F_L					1.0
// Coarse-graining of u_min and t_einstein for results
#define NUM_MC_POINTS			40

//
// Preferences with the graphing routines
//
#define OUTPUT_TYPE				"png"
#define OUTPUT_SIZE_X			1200
#define OUTPUT_SIZE_Y			750
// Seperation between model	points, in days, decimals allowed
#define MODEL_POINT_SPACING		0.05


// EOF