/*
 PC 4182 MPhys Project - Classification of Gravitational Microlensing Light Curves
 
 The theory for single-lens microlensing.
 
 Started: 30/04/06
 Last Modified: 12/05/06
 
 Mike Peel (http://www.mikepeel.net/) & Matthew Dennison (matthew.dennison@manchester.ac.uk)
 */

//
// Returns the magnification of a magnitude compared to the average magnitude.
//
double calc_magnification(double magnitude, double average)
{
	return pow(10.0, 0.4 * (average - magnitude));
}

//
// Starting with the magnification A, work out the impact parameter u
//
double calc_u(double A)
{
	return sqrt(-2.0 + (2.0 * A) / sqrt(A * A - 1.0));
}

//
// Return the magnitude corresponding to the theory values
//
double get_theory_magnitude(double time, double t_peak, double t_einstein, double u_min, double f_l, double m_base)
{
	double r, mu, mu_b;
	
	// Calculate r
	r = pow(((pow((time - t_peak), 2.0) / pow(t_einstein, 2.0)) + pow(u_min, 2.0)), 0.5);

	// Calculate mu
	mu = (pow(r, 2.0) + 2.0) / pow((pow(r, 4.0) + (4.0 * pow(r, 2.0))), 0.5);

	// Calculate mu_b
	mu_b = (mu * f_l) + 1 - f_l;
	
	// Finally, calculate the magnitude
	return (m_base - 2.5 * log10(mu_b));
};
